==> mgug4121a_1.8.4.tar.gz: mgug4121a/man/mgug4121aPATH2PROBE.Rd <==
\name{mgug4121aPATH2PROBE}
\alias{mgug4121aPATH2PROBE}
\title{Map between Kyoto Encyclopedia of Genes and Genomes (KEGG)
  pathway identifiers and Manufacturer Identifiers}
\description{
 mgug4121aPATH2PROBE is an R environment that provides mappings between
 KEGG ids and manufacturer ids.
}
\details{
  Each KEGG id is mapped to a named vector of manufacturer ids. The name
  represents the KEGG id and the vector contains all manufacturer ids
  that are found in that particular pathway. An \code{NA} is reported
  for any KEGG id that cannot be mapped to any manufacturer ids.

  Pathway name for a given pathway id can be obtained using the KEGG
  data package that can either be built using AnnBuilder or downloaded
  from Bioconductor \url{http://www.bioconductor.org}.

  Graphic presentations of pathways are searchable at
  \url{http://www.genome.ad.jp/kegg/pathway.html} using pathway ids as keys.
  
  Mappings were based on data provided by:

  KEGG:\url{http://gopher5/compbio/annotationSourceData/kegg/pathways}. Built: Release 34.0 (April 2005)

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue May 17 16:28:52 2005

  Package built Tue May 17 16:43:24 2005
}
\references{
\url{http://www.genome.ad.jp/kegg/}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(mgug4121aPATH2PROBE)
    # Remove pathway ids that do not map to any probe id
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    } 
}

\keyword{datasets}

==> mgug4121a_1.10.0.tar.gz: mgug4121a/man/mgug4121aPATH2PROBE.Rd <==
\name{mgug4121aPATH2PROBE}
\alias{mgug4121aPATH2PROBE}
\title{Map between Kyoto Encyclopedia of Genes and Genomes (KEGG)
  pathway identifiers and Manufacturer Identifiers}
\description{
 mgug4121aPATH2PROBE is an R environment that provides mappings between
 KEGG ids and manufacturer ids.
}
\details{
  Each KEGG id is mapped to a named vector of manufacturer ids. The name
  represents the KEGG id and the vector contains all manufacturer ids
  that are found in that particular pathway. An \code{NA} is reported
  for any KEGG id that cannot be mapped to any manufacturer ids.

  Pathway name for a given pathway id can be obtained using the KEGG
  data package that can either be built using AnnBuilder or downloaded
  from Bioconductor \url{http://www.bioconductor.org}.

  Graphic presentations of pathways are searchable at
  \url{http://www.genome.ad.jp/kegg/pathway.html} using pathway ids as keys.
  
  Mappings were based on data provided by:

  KEGG:\url{http://gopher5/compbio/annotationSourceData/kegg/pathways}. Built: Release 36.0, October 1, 2005

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue Oct  4 22:45:42 2005

  Package built Tue Oct  4 23:02:04 2005
}
\references{
\url{http://www.genome.ad.jp/kegg/}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(mgug4121aPATH2PROBE)
    # Remove pathway ids that do not map to any probe id
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    } 
}

\keyword{datasets}
